==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCardActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardActionsDescription } from "./WebCardActionsDescription";
/**
 * @hidden
 */
var WebCardActionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardActionsDescriptionMetadata, _super);
    function WebCardActionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardActionsDescriptionMetadata.b = function (a) {
        if (WebCardActionsDescriptionMetadata.a == null) {
            WebCardActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardActionsDescriptionMetadata.c(WebCardActionsDescriptionMetadata.a);
        }
        if (a.k(WebCardActionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardActions");
        a.item("__tagNameWC", "String:igc-card-actions");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Orientation", "ExportedType:string:CardActionsOrientation");
        a.item("Orientation@stringUnion", "WebComponents;React");
        a.item("Orientation@names", "Vertical;Horizontal");
    };
    WebCardActionsDescriptionMetadata.d = function (a) {
        WebCardActionsDescriptionMetadata.b(a);
        a.ac("WebCardActions", function () { return new WebCardActionsDescription(); });
        a.ab("WebCardActions", WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.$t = markType(WebCardActionsDescriptionMetadata, 'WebCardActionsDescriptionMetadata');
    WebCardActionsDescriptionMetadata.a = null;
    return WebCardActionsDescriptionMetadata;
}(Base));
export { WebCardActionsDescriptionMetadata };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/WebCardActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardActionsDescription } from "./WebCardActionsDescription";
/**
 * @hidden
 */
var WebCardActionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardActionsDescriptionMetadata, _super);
    function WebCardActionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardActionsDescriptionMetadata.b = function (a) {
        if (WebCardActionsDescriptionMetadata.a == null) {
            WebCardActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardActionsDescriptionMetadata.c(WebCardActionsDescriptionMetadata.a);
        }
        if (a.k(WebCardActionsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardActions");
        a.item("__tagNameWC", "String:igc-card-actions");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Orientation", "ExportedType:string:ContentOrientation");
        a.item("Orientation@stringUnion", "WebComponents;React");
        a.item("Orientation@names", "Horizontal;Vertical");
    };
    WebCardActionsDescriptionMetadata.d = function (a) {
        WebCardActionsDescriptionMetadata.b(a);
        a.ae("WebCardActions", function () { return new WebCardActionsDescription(); });
        a.ad("WebCardActions", WebCardActionsDescriptionMetadata.a);
    };
    WebCardActionsDescriptionMetadata.$t = markType(WebCardActionsDescriptionMetadata, 'WebCardActionsDescriptionMetadata');
    WebCardActionsDescriptionMetadata.a = null;
    return WebCardActionsDescriptionMetadata;
}(Base));
export { WebCardActionsDescriptionMetadata };
